#this script computes the temperature anomaly by country.
#modified from the replication data provided by Burke et al. (2015) at https://purl.stanford.edu/wb587wt4560

library(ncdf4)
library(maptools)
library(maps)
library(raster)

#setwd("myFolder")

#reading countries borders
cty=readShapePoly('input/countries/country.shp')  
#exclude Antarctica and svalbard
cty1 <- cty[cty@data[,3]!="Antarctica" & cty@data[,3]!="Svalbard",]  

#reading world population
pop = readAsciiGrid("input/populationData/glp00ag30.asc")
pop=as.matrix(pop)
pop=raster(t(pop),xmn=-180,xmx=180,ymn=-58,ymx=85)


#retreive temperature LGM anomalies 
fich_open = nc_open("input/sat_LGM_annan2013.nc")
sat = ncvar_get(fich_open,"SAT")
nc_close(fich_open)

#centering the file on the Atlantic
raster_sat=  raster(aperm(sat[1:180,90:1]),xmn=-180,xmx=180,ymn=-90,ymx=90)
#disaggregate to 0.5 
raster_disag = disaggregate(raster_sat,fact=4) 

diff_limited =  crop(raster_disag, pop_agg) 

Tdiff_pays <- extract(diff_limited,cty1,small=T,progress="text")  # returns a list where each element is the cell numbers in the pop raster that are covered by a given country.  
pop_pays <- extract(pop_agg,cty1,small=T,progress="text")

# if country only covered by one cell, or if no population in aggregated grids, 
#just report value of delta T in that cell
wtmn <- function(x,y) {if (length(x)>1 & sum(y)!=0) {weighted.mean(x,y)} else {mean(x)}} 
#compute temperature change, weighted by population 
Tdiff_w <- mapply(wtmn,Tdiff_pays,pop_pays) 

#write the file containing for each country
#the population-weighted temperature change 
out <- data.frame(cty1@data[,1:3],Tdiff_w)
write.csv(out,file="CountryTempChange_LGM05.csv",row.names=F)
